@@ -40,7 +40,7 @@ import digitalio
 
 from micropython import const
 
-__version__ = "5.1.17"
+__version__ = "5.1.19"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_LIS3DH.git"
 
 # Register addresses:
@@ -125,16 +125,16 @@ class LIS3DH:
 
         Could have the following values:
 
-        * DATA_RATE_400_HZ
-        * DATA_RATE_200_HZ
-        * DATA_RATE_100_HZ
-        * DATA_RATE_50_HZ
-        * DATA_RATE_25_HZ
-        * DATA_RATE_10_HZ
-        * DATA_RATE_1_HZ
-        * DATA_RATE_POWERDOWN
-        * DATA_RATE_LOWPOWER_1K6HZ
-        * DATA_RATE_LOWPOWER_5KHZ.
+        * DATARATE_400_HZ
+        * DATARATE_200_HZ
+        * DATARATE_100_HZ
+        * DATARATE_50_HZ
+        * DATARATE_25_HZ
+        * DATARATE_10_HZ
+        * DATARATE_1_HZ
+        * DATARATE_POWERDOWN
+        * DATARATE_LOWPOWER_1K6HZ
+        * DATARATE_LOWPOWER_5KHZ.
 
         """
         ctl1 = self._read_register_byte(_REG_CTRL1)
