@@ -14,7 +14,7 @@ if hasattr(board, "ACCELEROMETER_SCL"):
     int1 = digitalio.DigitalInOut(board.ACCELEROMETER_INTERRUPT)
     lis3dh = adafruit_lis3dh.LIS3DH_I2C(i2c, address=0x19, int1=int1)
 else:
-    i2c = busio.I2C(board.SCL, board.SDA)
+    i2c = board.I2C()  # uses board.SCL and board.SDA
     int1 = digitalio.DigitalInOut(
         board.D9
     )  # Set this to the correct pin for the interrupt!
